@@ -1,9 +1,12 @@
 package Setup::Unix::Group;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.12'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -12,10 +15,13 @@ our @EXPORT_OK = qw(setup_unix_group);
 use PerlX::Maybe;
 use Unix::Passwd::File;
 
-our $VERSION = '0.11'; # VERSION
-
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Setup Unix group (existence)',
+};
+
 my %common_args = (
     etc_dir => {
         summary => 'Location of passwd files',
@@ -273,261 +279,7 @@ Setup::Unix::Group - Setup Unix group (existence)
 
 =head1 VERSION
 
-This document describes version 0.11 of Setup::Unix::Group (from Perl distribution Setup-Unix-User), released on 2014-05-18.
-
-=head1 FUNCTIONS
-
-
-=head2 addgroup(%args) -> [status, msg, result, meta]
-
-Add group.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<etc_dir> => I<str> (default: "/etc")
-
-Location of passwd files.
-
-=item * B<gid> => I<int>
-
-Add with specified GID.
-
-If not specified, will search an unused GID from C<min_new_gid> to C<max_new_gid>.
-
-If specified, will accept non-unique GID (that which has been used by other
-group).
-
-=item * B<group> => I<str>
-
-Group name.
-
-=item * B<max_gid> => I<int> (default: 65534)
-
-Specify range for new GID.
-
-If a free GID between C<min_gid> and C<max_gid> is not available, an error is
-returned.
-
-Passed to Unix::Passwd::File's C<max_new_gid>.
-
-=item * B<min_gid> => I<int> (default: 1000)
-
-Specify range for new GID.
-
-If a free GID between C<min_gid> and C<max_gid> is not available, an error is
-returned.
-
-Passed to Unix::Passwd::File's C<min_new_gid>.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-
-=head2 delgroup(%args) -> [status, msg, result, meta]
-
-Delete group.
-
-Fixed state: group does not exist.
-
-Fixable state: group exists.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<etc_dir> => I<str> (default: "/etc")
-
-Location of passwd files.
-
-=item * B<group> => I<str>
-
-Group name.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-
-=head2 setup_unix_group(%args) -> [status, msg, result, meta]
-
-Setup Unix group (existence).
-
-On do, will create Unix group if not already exists. The created GID will be
-returned in the result (C<{gid => GID}>). If C<should_already_exist> is set to
-true, won't create but only require that group already exists. If C<should_exist>
-is set to false, will delete existing group instead of creating it.
-
-On undo, will delete Unix group previously created.
-
-On redo, will recreate the Unix group with the same GID.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<etc_dir> => I<str> (default: "/etc")
-
-Location of passwd files.
-
-=item * B<group> => I<str>
-
-Group name.
-
-=item * B<max_new_gid> => I<int> (default: 65534)
-
-Specify range for new GID.
-
-If a free GID between C<min_gid> and C<max_gid> is not available, an error is
-returned.
-
-Passed to Unix::Passwd::File's C<max_new_gid>.
-
-=item * B<min_new_gid> => I<int> (default: 1000)
-
-Specify range for new GID.
-
-If a free GID between C<min_gid> and C<max_gid> is not available, an error is
-returned.
-
-Passed to Unix::Passwd::File's C<min_new_gid>.
-
-=item * B<new_gid> => I<int>
-
-Add with specified GID.
-
-If not specified, will search an unused GID from C<min_new_gid> to C<max_new_gid>.
-
-If specified, will accept non-unique GID (that which has been used by other
-group).
-
-=item * B<should_already_exist> => I<bool>
-
-Whether group should already exist.
-
-=item * B<should_exist> => I<bool> (default: 1)
-
-Whether group should exist.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+This document describes version 0.12 of Setup::Unix::Group (from Perl distribution Setup-Unix-User), released on 2015-08-18.
 
 =head1 FAQ
 
@@ -537,13 +289,283 @@ L<Setup>
 
 L<Setup::Unix::User>
 
+=head1 FUNCTIONS
+
+
+=head2 addgroup(%args) -> [status, msg, result, meta]
+
+{en_US Add group}.
+
+This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<etc_dir> => I<str> (default: "/etc")
+
+{en_US Location of passwd files}.
+
+=item * B<gid> => I<int>
+
+{en_US Add with specified GID}.
+
+{en_US 
+If not specified, will search an unused GID from C<min_new_gid> to C<max_new_gid>.
+
+If specified, will accept non-unique GID (that which has been used by other
+group).
+}
+
+=item * B<group> => I<str>
+
+{en_US Group name}.
+
+=item * B<max_gid> => I<int> (default: 65534)
+
+{en_US Specify range for new GID}.
+
+{en_US 
+If a free GID between C<min_gid> and C<max_gid> is not available, an error is
+returned.
+
+Passed to Unix::Passwd::File's C<max_new_gid>.
+}
+
+=item * B<min_gid> => I<int> (default: 1000)
+
+{en_US Specify range for new GID}.
+
+{en_US 
+If a free GID between C<min_gid> and C<max_gid> is not available, an error is
+returned.
+
+Passed to Unix::Passwd::File's C<min_new_gid>.
+}
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-tx_action> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_action_id> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_recovery> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_rollback> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_v> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 delgroup(%args) -> [status, msg, result, meta]
+
+{en_US Delete group}.
+
+{en_US 
+Fixed state: group does not exist.
+
+Fixable state: group exists.
+}
+
+This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<etc_dir> => I<str> (default: "/etc")
+
+{en_US Location of passwd files}.
+
+=item * B<group> => I<str>
+
+{en_US Group name}.
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-tx_action> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_action_id> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_recovery> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_rollback> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_v> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 setup_unix_group(%args) -> [status, msg, result, meta]
+
+{en_US Setup Unix group (existence)}.
+
+{en_US 
+On do, will create Unix group if not already exists. The created GID will be
+returned in the result (C<< {gid =E<gt> GID} >>). If C<should_already_exist> is set to
+true, won't create but only require that group already exists. If C<should_exist>
+is set to false, will delete existing group instead of creating it.
+
+On undo, will delete Unix group previously created.
+
+On redo, will recreate the Unix group with the same GID.
+}
+
+This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<etc_dir> => I<str> (default: "/etc")
+
+{en_US Location of passwd files}.
+
+=item * B<group> => I<str>
+
+{en_US Group name}.
+
+=item * B<max_new_gid> => I<int> (default: 65534)
+
+{en_US Specify range for new GID}.
+
+{en_US 
+If a free GID between C<min_gid> and C<max_gid> is not available, an error is
+returned.
+
+Passed to Unix::Passwd::File's C<max_new_gid>.
+}
+
+=item * B<min_new_gid> => I<int> (default: 1000)
+
+{en_US Specify range for new GID}.
+
+{en_US 
+If a free GID between C<min_gid> and C<max_gid> is not available, an error is
+returned.
+
+Passed to Unix::Passwd::File's C<min_new_gid>.
+}
+
+=item * B<new_gid> => I<int>
+
+{en_US Add with specified GID}.
+
+{en_US 
+If not specified, will search an unused GID from C<min_new_gid> to C<max_new_gid>.
+
+If specified, will accept non-unique GID (that which has been used by other
+group).
+}
+
+=item * B<should_already_exist> => I<bool>
+
+{en_US Whether group should already exist}.
+
+=item * B<should_exist> => I<bool> (default: 1)
+
+{en_US Whether group should exist}.
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-tx_action> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_action_id> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_recovery> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_rollback> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_v> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Setup-Unix-User>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Setup-Unix-User>.
+Source repository is at L<https://github.com/perlancar/perl-Setup-Unix-User>.
 
 =head1 BUGS
 
@@ -555,11 +577,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
