@@ -1,10 +1,13 @@
 package Setup::Unix::User;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.12'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use List::Util qw(first);
 use PerlX::Maybe;
@@ -15,10 +18,13 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(setup_unix_user);
 
-our $VERSION = '0.11'; # VERSION
-
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Setup Unix user (existence, home dir, group memberships)',
+};
+
 sub _rand_pass {
     require Text::Password::Pronounceable;
     Text::Password::Pronounceable->generate(10, 16);
@@ -505,368 +511,7 @@ Setup::Unix::User - Setup Unix user (existence, home dir, group memberships)
 
 =head1 VERSION
 
-This document describes version 0.11 of Setup::Unix::User (from Perl distribution Setup-Unix-User), released on 2014-05-18.
-
-=head1 FUNCTIONS
-
-
-=head2 add_delete_user_groups(%args) -> [status, msg, result, meta]
-
-Add/delete user from group memberships.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<add_to>* => I<array>
-
-=item * B<delete_from>* => I<array>
-
-=item * B<etc_dir> => I<str> (default: "/etc")
-
-Location of passwd files.
-
-=item * B<user> => I<str>
-
-User name.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-
-=head2 adduser(%args) -> [status, msg, result, meta]
-
-Add user.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<etc_dir> => I<str> (default: "/etc")
-
-Location of passwd files.
-
-=item * B<gecos> => I<str>
-
-=item * B<gid> => I<int>
-
-When creating group, use specific GID.
-
-If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
-
-=item * B<group> => I<str>
-
-Group name.
-
-=item * B<home> => I<str>
-
-=item * B<max_gid> => I<int> (default: 65534)
-
-=item * B<max_uid> => I<int> (default: 65534)
-
-=item * B<min_gid> => I<int> (default: 1000)
-
-=item * B<min_uid> => I<int> (default: 1000)
-
-=item * B<pass> => I<str>
-
-=item * B<shell> => I<str>
-
-=item * B<uid> => I<int>
-
-Add with specified UID.
-
-If not specified, will search an unused UID from C<min_uid> to C<max_uid>.
-
-=item * B<user> => I<str>
-
-User name.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-
-=head2 deluser(%args) -> [status, msg, result, meta]
-
-Delete user.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<etc_dir> => I<str> (default: "/etc")
-
-Location of passwd files.
-
-=item * B<user> => I<str>
-
-User name.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-
-=head2 setup_unix_user(%args) -> [status, msg, result, meta]
-
-Setup Unix user (existence, group memberships).
-
-On do, will create Unix user if not already exists. And also make sure user
-belong to specified groups (and not belong to unwanted groups). Return the
-created UID/GID in the result.
-
-On undo, will delete Unix user (along with its initially created home dir and
-files) if it was created by this function. Also will restore old group
-memberships.
-
-This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
-
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<create_home> => I<bool> (default: 1)
-
-Whether to create home directory when creating user.
-
-=item * B<etc_dir> => I<str> (default: "/etc")
-
-Location of passwd files.
-
-=item * B<group> => I<str>
-
-Group name.
-
-=item * B<max_gid> => I<any>
-
-=item * B<max_new_gid> => I<any>
-
-=item * B<max_new_uid> => I<any>
-
-=item * B<max_uid> => I<any>
-
-=item * B<member_of> => I<array>
-
-List of Unix group names that the user must be member of.
-
-If not specified, member_of will be set to just the primary group. The primary
-group will always be added even if not specified.
-
-=item * B<min_gid> => I<any>
-
-=item * B<min_new_gid> => I<any>
-
-=item * B<min_new_uid> => I<any>
-
-=item * B<min_uid> => I<any>
-
-=item * B<new_gecos> => I<str>
-
-=item * B<new_gid> => I<int>
-
-When creating group, use specific GID.
-
-If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
-
-=item * B<new_home> => I<str>
-
-=item * B<new_max_gid> => I<int> (default: 65534)
-
-=item * B<new_max_uid> => I<int> (default: 65534)
-
-=item * B<new_min_gid> => I<int> (default: 1000)
-
-=item * B<new_min_uid> => I<int> (default: 1000)
-
-=item * B<new_pass> => I<str>
-
-=item * B<new_shell> => I<str>
-
-=item * B<new_uid> => I<int>
-
-Add with specified UID.
-
-If not specified, will search an unused UID from C<min_uid> to C<max_uid>.
-
-=item * B<not_member_of> => I<array>
-
-List of Unix group names that the user must NOT be member of.
-
-=item * B<should_already_exist> => I<bool>
-
-Whether user should already exist.
-
-=item * B<should_exist> => I<bool> (default: 1)
-
-Whether user should exist.
-
-=item * B<skel_dir> => I<str> (default: "/etc/skel")
-
-Directory to get skeleton files when creating user.
-
-=item * B<use_skel> => I<bool> (default: 1)
-
-Whether to copy files from skeleton dir when creating user.
-
-=item * B<user> => I<str>
-
-User name.
-
-=back
-
-Special arguments:
-
-=over 4
-
-=item * B<-tx_action> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_action_id> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_recovery> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_rollback> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=item * B<-tx_v> => I<str>
-
-For more information on transaction, see L<Rinci::Transaction>.
-
-=back
-
-Return value:
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+This document describes version 0.12 of Setup::Unix::User (from Perl distribution Setup-Unix-User), released on 2015-08-18.
 
 =head1 FAQ
 
@@ -884,13 +529,386 @@ L<Setup>
 
 L<Setup::Unix::Group>
 
+=head1 FUNCTIONS
+
+
+=head2 add_delete_user_groups(%args) -> [status, msg, result, meta]
+
+{en_US Add/delete user from group memberships}.
+
+This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<add_to>* => I<array[str]>
+
+=item * B<delete_from>* => I<array[str]>
+
+=item * B<etc_dir> => I<str> (default: "/etc")
+
+{en_US Location of passwd files}.
+
+=item * B<user> => I<str>
+
+{en_US User name}.
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-tx_action> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_action_id> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_recovery> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_rollback> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_v> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 adduser(%args) -> [status, msg, result, meta]
+
+{en_US Add user}.
+
+This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<etc_dir> => I<str> (default: "/etc")
+
+{en_US Location of passwd files}.
+
+=item * B<gecos> => I<str>
+
+=item * B<gid> => I<int>
+
+{en_US When creating group, use specific GID}.
+
+{en_US 
+If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
+}
+
+=item * B<group> => I<str>
+
+{en_US Group name}.
+
+=item * B<home> => I<str>
+
+=item * B<max_gid> => I<int> (default: 65534)
+
+=item * B<max_uid> => I<int> (default: 65534)
+
+=item * B<min_gid> => I<int> (default: 1000)
+
+=item * B<min_uid> => I<int> (default: 1000)
+
+=item * B<pass> => I<str>
+
+=item * B<shell> => I<str>
+
+=item * B<uid> => I<int>
+
+{en_US Add with specified UID}.
+
+{en_US 
+If not specified, will search an unused UID from C<min_uid> to C<max_uid>.
+}
+
+=item * B<user> => I<str>
+
+{en_US User name}.
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-tx_action> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_action_id> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_recovery> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_rollback> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_v> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 deluser(%args) -> [status, msg, result, meta]
+
+{en_US Delete user}.
+
+This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<etc_dir> => I<str> (default: "/etc")
+
+{en_US Location of passwd files}.
+
+=item * B<user> => I<str>
+
+{en_US User name}.
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-tx_action> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_action_id> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_recovery> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_rollback> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_v> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 setup_unix_user(%args) -> [status, msg, result, meta]
+
+{en_US Setup Unix user (existence, group memberships)}.
+
+{en_US 
+On do, will create Unix user if not already exists. And also make sure user
+belong to specified groups (and not belong to unwanted groups). Return the
+created UID/GID in the result.
+
+On undo, will delete Unix user (along with its initially created home dir and
+files) if it was created by this function. Also will restore old group
+memberships.
+}
+
+This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<create_home> => I<bool> (default: 1)
+
+{en_US Whether to create home directory when creating user}.
+
+=item * B<etc_dir> => I<str> (default: "/etc")
+
+{en_US Location of passwd files}.
+
+=item * B<group> => I<str>
+
+{en_US Group name}.
+
+=item * B<max_gid> => I<any>
+
+=item * B<max_new_gid> => I<any>
+
+=item * B<max_new_uid> => I<any>
+
+=item * B<max_uid> => I<any>
+
+=item * B<member_of> => I<array[str]>
+
+{en_US List of Unix group names that the user must be member of}.
+
+{en_US 
+If not specified, member_of will be set to just the primary group. The primary
+group will always be added even if not specified.
+}
+
+=item * B<min_gid> => I<any>
+
+=item * B<min_new_gid> => I<any>
+
+=item * B<min_new_uid> => I<any>
+
+=item * B<min_uid> => I<any>
+
+=item * B<new_gecos> => I<str>
+
+=item * B<new_gid> => I<int>
+
+{en_US When creating group, use specific GID}.
+
+{en_US 
+If not specified, will search an unused GID from C<min_gid> to C<max_gid>.
+}
+
+=item * B<new_home> => I<str>
+
+=item * B<new_max_gid> => I<int> (default: 65534)
+
+=item * B<new_max_uid> => I<int> (default: 65534)
+
+=item * B<new_min_gid> => I<int> (default: 1000)
+
+=item * B<new_min_uid> => I<int> (default: 1000)
+
+=item * B<new_pass> => I<str>
+
+=item * B<new_shell> => I<str>
+
+=item * B<new_uid> => I<int>
+
+{en_US Add with specified UID}.
+
+{en_US 
+If not specified, will search an unused UID from C<min_uid> to C<max_uid>.
+}
+
+=item * B<not_member_of> => I<array[str]>
+
+{en_US List of Unix group names that the user must NOT be member of}.
+
+=item * B<should_already_exist> => I<bool>
+
+{en_US Whether user should already exist}.
+
+=item * B<should_exist> => I<bool> (default: 1)
+
+{en_US Whether user should exist}.
+
+=item * B<skel_dir> => I<str> (default: "/etc/skel")
+
+{en_US Directory to get skeleton files when creating user}.
+
+=item * B<use_skel> => I<bool> (default: 1)
+
+{en_US Whether to copy files from skeleton dir when creating user}.
+
+=item * B<user> => I<str>
+
+{en_US User name}.
+
+=back
+
+Special arguments:
+
+=over 4
+
+=item * B<-tx_action> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_action_id> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_recovery> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_rollback> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=item * B<-tx_v> => I<str>
+
+For more information on transaction, see L<Rinci::Transaction>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Setup-Unix-User>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Setup-Unix-User>.
+Source repository is at L<https://github.com/perlancar/perl-Setup-Unix-User>.
 
 =head1 BUGS
 
@@ -902,11 +920,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
